Learn R Programming

dagLogo (version 1.10.2)

prepareProteome: prepare proteome for background building

Description

prepare proteome from UniProt webserver or a fasta file

Usage

prepareProteome(UniProt.ws, fasta, species="unknown")

Arguments

UniProt.ws
an object of UniProt.ws
fasta
fasta file name or an object of AAStringSet
species
an character to assign the species of the proteome

Value

an object of Proteome which contain protein sequence information

See Also

formatSequence, buildBackgroundModel

Examples

Run this code
    if(interactive()){
        library(UniProt.ws)
        UniProt.ws <- UniProt.ws(taxId=7227)
        proteome <- prepareProteome(UniProt.ws, species="Drosophila melanogaster")
    }

Run the code above in your browser using DataLab