dagPeptides-class: Class "dagPeptides"
Description
An object of class "dagPeptides" represents the information of peptides.
Objects from the Class
Objects can be created by calls of the form
new("dagPeptides", data, peptides, upstreamOffset, downstreamOffset, type).Slots
data- Object of class
"data.frame" The details of the input sequences.
It includes the columns: IDs, anchorAA (anchor Amino Acid), anchorPos (anchor Position),
peptide (protein peptide), anchor, upstream, downstream (peptides in given upstream and downstream offset from anchor) peptides- code"matrix" The input peptides. Each column contains one peptide in that position
upstreamOffset"numeric" The upstream offset from anchor downstreamOffset"numeric" The downstream offset from anchor type"charactger" ID type of inputs