Objects from the Class
Objects can be created by calls of the form
new("dagBackground", group="character",
difference="matrix",
zscore="matrix",
pvalue="matrix",
background="matrix",
motif="matrix",
upstream="numeric",
downstream="numeric").Slots
group- Object of class
"character" could be "null", "classic", "charge", "chemistry", "hydrophobicity" difference- code"matrix" the difference of inputs from background for each amino acid in each position
zscore- code"matrix" z score for each amino acid in each position
pvalue- code"matrix" pvalue for each amino acid in each position
background- code"matrix" background frequencies for each amino acid in each position
motif- code"matrix" inputs frequencies for each amino acid in each position
upstream"numeric" The upstream offset from anchor downstream"numeric" The downstream offset from anchor